==> beast-privilege-api-2.6.6-20230316.084232-8-sources.jar: com/thebeastshop/privilege/vo/KeyMemberMemorialRecordVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class KeyMemberMemorialRecordVO implements Serializable {
    private Integer id;
    private Integer memorialId;
    private Integer type;
    private String name;
    private Date date;
    private Integer result;
    private String remark;
    private String orderCode;
    private Date createTime;
    private Date updateTime;
    private Integer creatorId;
    private String creatorName;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getMemorialId() {
        return memorialId;
    }

    public void setMemorialId(Integer memorialId) {
        this.memorialId = memorialId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    public Integer getResult() {
        return result;
    }

    public void setResult(Integer result) {
        this.result = result;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getOrderCode() {
        return orderCode;
    }

    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }



}

==> beast-privilege-api-2.6.6-20230320.060605-10-sources.jar: com/thebeastshop/privilege/vo/KeyMemberMemorialRecordVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;

public class KeyMemberMemorialRecordVO implements Serializable {
    private Integer id;
    private Integer memorialId;
    private Integer type; //纪念日类型 1：系统 2：个人
    private String name; //纪念日名称
    private Date date; //纪念日日期
    private Integer result; //处理结果 1：已完成 2：无需处理

    private Integer status; //状态 1:已完成,2:无需处理,3:未处理,4:处理中
    private String remark; //备注
    private String orderCode; //订单号
    private Date createTime;
    private Date updateTime;
    private Integer creatorId;
    private String creatorName;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getMemorialId() {
        return memorialId;
    }

    public void setMemorialId(Integer memorialId) {
        this.memorialId = memorialId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    public Integer getResult() {
        return result;
    }

    public void setResult(Integer result) {
        this.result = result;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getOrderCode() {
        return orderCode;
    }

    public void setOrderCode(String orderCode) {
        this.orderCode = orderCode;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getCreatorId() {
        return creatorId;
    }

    public void setCreatorId(Integer creatorId) {
        this.creatorId = creatorId;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }


}
